@@ -327,6 +327,22 @@ arv_camera_set_pixel_format (ArvCamera *camera, ArvPixelFormat format)
 	arv_device_set_integer_feature_value (camera->priv->device, "PixelFormat", format);
 }
 
+/**
+ * arv_camera_set_pixel_format_from_string:
+ * @camera: a #ArvCamera
+ * @format: pixel format
+ *
+ * Defines pixel format described by a string.
+ */
+
+void
+arv_camera_set_pixel_format_from_string (ArvCamera *camera, const char * format)
+{
+        g_return_if_fail (ARV_IS_CAMERA (camera));
+
+        arv_device_set_string_feature_value (camera->priv->device, "PixelFormat", format);
+}
+
 /**
  * arv_camera_get_pixel_format:
  * @camera: a #ArvCamera
@@ -364,7 +380,7 @@ arv_camera_get_pixel_format_as_string (ArvCamera *camera)
  *
  * Retrieves the list of all available pixel formats.
  *
- * Returns: (array length=n_pixel_formats) (transfer full): a newly allocated array of #ArvPixelFormat
+ * Returns: (array length=n_pixel_formats) (transfer container): a newly allocated array of #ArvPixelFormat
  */
 
 gint64 *
@@ -372,7 +388,78 @@ arv_camera_get_available_pixel_formats (ArvCamera *camera, guint *n_pixel_format
 {
 	g_return_val_if_fail (ARV_IS_CAMERA (camera), NULL);
 
-	return arv_device_get_enumeration_feature_available_values (camera->priv->device, "PixelFormat", n_pixel_formats);
+	return arv_device_get_available_enumeration_feature_values (camera->priv->device, "PixelFormat", n_pixel_formats);
+}
+
+/**
+ * arv_camera_get_available_pixel_formats_as_strings:
+ * @camera: a #ArvCamera
+ * @n_pixel_formats: (out): number of different pixel formats
+ *
+ * Retrieves the list of all available pixel formats as strings.
+ *
+ * Returns: (array length=n_pixel_formats) (transfer container): a newly allocated array of strings.
+ */
+
+const char **
+arv_camera_get_available_pixel_formats_as_strings (ArvCamera *camera, guint *n_pixel_formats)
+{
+	g_return_val_if_fail (ARV_IS_CAMERA (camera), NULL);
+
+	return arv_device_get_available_enumeration_feature_values_as_strings (camera->priv->device, "PixelFormat", n_pixel_formats);
+}
+
+/**
+ * arv_camera_get_available_pixel_formats_as_display_names:
+ * @camera: a #ArvCamera
+ * @n_pixel_formats: (out): number of different pixel formats
+ *
+ * Retrieves the list of all available pixel formats as display names.
+ * In general, these human-readable strings cannot be used as settings.
+ *
+ * Returns: (array length=n_pixel_formats) (transfer container): a newly allocated array of string constants.
+ */
+
+const char **
+arv_camera_get_available_pixel_formats_as_display_names (ArvCamera *camera, guint *n_pixel_formats)
+{
+	ArvGcNode *node;
+	const GSList *entries, *iter;
+	const char **strings;
+	const char *string = NULL;
+	gboolean is_available, is_implemented;
+	int i;
+
+	g_return_val_if_fail (n_pixel_formats != NULL, NULL);
+	*n_pixel_formats = 0;
+
+	g_return_val_if_fail (ARV_IS_CAMERA (camera), NULL);
+	node = arv_device_get_feature (camera->priv->device, "PixelFormat");
+
+	if (ARV_IS_GC_ENUMERATION (node))
+		entries = arv_gc_enumeration_get_entries (ARV_GC_ENUMERATION (node));
+	else
+		return NULL;
+
+	strings = g_new (const char *, g_slist_length ((GSList*)entries));
+	i = 0;
+	for (iter = entries; iter != NULL; iter = iter->next) {
+		is_available = arv_gc_feature_node_is_available (iter->data, NULL);
+		is_implemented = arv_gc_feature_node_is_implemented (iter->data, NULL);
+		if (is_available && is_implemented) {
+			string = arv_gc_feature_node_get_display_name (iter->data, NULL);
+			if (string == NULL)
+				string = arv_gc_feature_node_get_name (iter->data);
+			if (string == NULL) {
+				g_free (strings);
+				return NULL;
+			}
+			strings[i++] = string;
+		}
+	}
+
+	*n_pixel_formats = i;
+	return strings;
 }
 
 /* Acquisition control */
@@ -852,6 +939,26 @@ arv_camera_get_device (ArvCamera *camera)
 	return camera->priv->device;
 }
 
+/**
+ * arv_camera_is_frame_rate_available:
+ * @camera: a #ArvCamera
+ * Returns: TRUE if FrameRate feature is available
+ */
+
+gboolean
+arv_camera_is_frame_rate_available (ArvCamera *camera)
+{
+	g_return_val_if_fail (ARV_IS_CAMERA (camera), FALSE);
+
+	switch (camera->priv->vendor) {
+		case ARV_CAMERA_VENDOR_BASLER:
+		case ARV_CAMERA_VENDOR_PROSILICA:
+			return arv_device_get_feature (camera->priv->device, "AcquisitionFrameRateAbs") != NULL;
+		case ARV_CAMERA_VENDOR_UNKNOWN:
+		default:
+			return arv_device_get_feature (camera->priv->device, "AcquisitionFrameRate") != NULL;
+	}
+}
 /**
  * arv_camera_is_exposure_time_available:
  * @camera: a #ArvCamera
@@ -1053,12 +1160,12 @@ arv_camera_class_init (ArvCameraClass *camera_class)
 	object_class->get_property = arv_camera_get_property;
 
 	g_object_class_install_property (object_class,
-									 PROP_CAMERA_DEVICE,
-									 g_param_spec_object ("device",
-														  "device",
-														  "the device associated with this camera",
-														  ARV_TYPE_DEVICE,
-														  G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+					 PROP_CAMERA_DEVICE,
+					 g_param_spec_object ("device",
+							      "device",
+							      "the device associated with this camera",
+							      ARV_TYPE_DEVICE,
+							      G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 G_DEFINE_TYPE (ArvCamera, arv_camera, G_TYPE_OBJECT)
