@@ -458,7 +458,7 @@ arv_device_get_float_feature_bounds (ArvDevice *device, const char *feature, dou
 }
 
 gint64 *
-arv_device_get_enumeration_feature_available_values (ArvDevice *device, const char *feature, guint *n_values)
+arv_device_get_available_enumeration_feature_values (ArvDevice *device, const char *feature, guint *n_values)
 {
 	ArvGcNode *node;
 	GError *error = NULL;
@@ -487,6 +487,47 @@ arv_device_get_enumeration_feature_available_values (ArvDevice *device, const ch
 	return values;
 }
 
+/**
+ * arv_device_get_available_enumeration_feature_values_as_strings:
+ * @device: an #ArvDevice
+ * @feature: feature name
+ * @n_values: placeholder for the number of returned values
+ *
+ * Get all the available values of @feature, as strings.
+ *
+ * Returns: (array length=n_values) (transfer container): a newly created array of const strings, which must freed after use using g_free.
+ */
+
+const char **
+arv_device_get_available_enumeration_feature_values_as_strings (ArvDevice *device, const char *feature, guint *n_values)
+{
+	ArvGcNode *node;
+	GError *error = NULL;
+	const char ** strings = NULL;
+
+	if (n_values != NULL)
+		*n_values = 0;
+
+	g_return_val_if_fail (ARV_IS_DEVICE (device), NULL);
+
+	node = arv_device_get_feature (device, feature);
+
+	if (ARV_IS_GC_ENUMERATION (node))
+		strings = arv_gc_enumeration_get_available_string_values (ARV_GC_ENUMERATION (node), n_values, &error);
+	else
+		arv_warning_device ("[ArvDevice::get_enumeration_feature_available_strings] Node '%s' is not an enumeration",
+				    feature);
+
+	if (error != NULL) {
+		_set_status (device, error->code, error->message);
+		g_error_free (error);
+
+		return NULL;
+	}
+
+	return strings;
+}
+
 ArvDeviceStatus
 arv_device_get_status (ArvDevice *device)
 {
