@@ -47,6 +47,7 @@ arv_interface_clear_device_ids (ArvInterface *interface)
 	for (i = 0; i < interface->priv->device_ids->len; i++) {
 		g_free (g_array_index (interface->priv->device_ids, ArvInterfaceDeviceIds *, i)->device);
 		g_free (g_array_index (interface->priv->device_ids, ArvInterfaceDeviceIds *, i)->physical);
+		g_free (g_array_index (interface->priv->device_ids, ArvInterfaceDeviceIds *, i)->address);
 	}
 	g_array_set_size (interface->priv->device_ids, 0);
 }
@@ -135,6 +136,34 @@ arv_interface_get_device_physical_id (ArvInterface *interface, unsigned int inde
 
 	return g_array_index (interface->priv->device_ids, ArvInterfaceDeviceIds *, index)->physical;
 }
+
+/**
+ * arv_interface_get_device_address
+ * @interface: a #ArvInterface
+ * @index: device index
+ * Return value: (transfer none): the device address
+ *
+ * queries the device address (IP address in the case of an ethernet camera). Useful
+ * for constructing manual connections to devices using @arv_gv_device_new
+ *
+ * Prior to this call the @arv_interface_update_device_list
+ * function must be called.
+ *
+ * since: 0.1.14
+ **/
+
+const char *
+arv_interface_get_device_address (ArvInterface *interface, unsigned int index)
+{
+	g_return_val_if_fail (ARV_IS_INTERFACE (interface), 0);
+	g_return_val_if_fail (interface->priv->device_ids != NULL, 0);
+
+	if (index >= interface->priv->device_ids->len)
+		return NULL;
+
+	return g_array_index (interface->priv->device_ids, ArvInterfaceDeviceIds *, index)->address;
+}
+
 /**
  * arv_interface_open_device
  * @interface: a #ArvInterface
