@@ -1,6 +1,6 @@
 /* Aravis - Digital camera library
  *
- * Copyright © 2009-2011 Emmanuel Pacaud
+ * Copyright © 2009-2012 Emmanuel Pacaud
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,13 +20,13 @@
  * Author: Emmanuel Pacaud <emmanuel@gnome.org>
  */
 
+#include <arvconfig.h>
 #include <gtk/gtk.h>
 #include <gst/gst.h>
 #include <gst/app/gstappsrc.h>
 #include <gst/interfaces/xoverlay.h>
 #include <gdk/gdkx.h>
 #include <arv.h>
-#include <arvenumtypes.h>
 #include <stdlib.h>
 #include <math.h>
 #include <glib/gi18n-lib.h>
@@ -50,12 +50,20 @@ typedef struct {
 
 	GstElement *pipeline;
 	GstElement *appsrc;
+	GstElement *transform;
+
+	guint rotation;
+	gboolean flip_vertical;
+	gboolean flip_horizontal;
 
 	guint64 timestamp_offset;
 	guint64 last_timestamp;
 
 	GtkWidget *main_window;
 	GtkWidget *snapshot_button;
+	GtkWidget *rotate_cw_button;
+	GtkWidget *flip_vertical_toggle;
+	GtkWidget *flip_horizontal_toggle;
 	GtkWidget *drawing_area;
 	GtkWidget *camera_combo_box;
 	GtkWidget *trigger_combo_box;
@@ -402,6 +410,73 @@ arv_viewer_snapshot_cb (GtkButton *button, ArvViewer *viewer)
 	g_date_time_unref (date);
 }
 
+static void
+_update_transform (ArvViewer *viewer)
+{
+	static const gint methods[4][4] = {
+		{0, 1, 2, 3},
+		{4, 6, 5, 7},
+		{5, 7, 4, 6},
+		{2, 3, 0, 1}
+	};
+	int index = (viewer->flip_horizontal ? 1 : 0) + (viewer->flip_vertical ? 2 : 0);
+
+	g_object_set (viewer->transform, "method", methods[index][viewer->rotation % 4], NULL);
+}
+
+void
+arv_viewer_rotate_cw_cb (GtkButton *button, ArvViewer *viewer)
+{
+	viewer->rotation = (viewer->rotation + 1) % 4;
+
+	_update_transform (viewer);
+}
+
+void
+arv_viewer_flip_horizontal_cb (GtkToggleButton *toggle, ArvViewer *viewer)
+{
+	viewer->flip_horizontal = gtk_toggle_button_get_active (toggle);
+
+	_update_transform (viewer);
+}
+
+void
+arv_viewer_flip_vertical_cb (GtkToggleButton *toggle, ArvViewer *viewer)
+{
+	viewer->flip_vertical = gtk_toggle_button_get_active (toggle);
+
+	_update_transform (viewer);
+}
+
+static GstBusSyncReply
+bus_sync_handler (GstBus *bus, GstMessage *message, gpointer user_data)
+{
+	ArvViewer *viewer = user_data;
+
+	if (GST_MESSAGE_TYPE (message) != GST_MESSAGE_ELEMENT)
+		return GST_BUS_PASS;
+	if (!gst_structure_has_name (message->structure, "prepare-xwindow-id"))
+		return GST_BUS_PASS;
+
+	if (viewer->video_window_xid != 0) {
+		GstXOverlay *xoverlay;
+
+		xoverlay = GST_X_OVERLAY (GST_MESSAGE_SRC (message));
+		gst_x_overlay_set_window_handle (xoverlay, viewer->video_window_xid);
+
+		if (g_strcmp0 (G_OBJECT_TYPE_NAME (xoverlay), "GstXvImageSink"))
+			g_object_set (xoverlay, "draw-borders", TRUE, NULL);
+
+		g_object_set (xoverlay, "force-aspect-ratio", TRUE, "sync", FALSE, NULL);
+	} else {
+		g_warning ("Should have obtained video_window_xid by now!");
+	}
+
+	gst_message_unref (message);
+
+	return GST_BUS_DROP;
+}
+
 void
 arv_viewer_select_camera_cb (GtkComboBox *combo_box, ArvViewer *viewer)
 {
@@ -409,7 +484,8 @@ arv_viewer_select_camera_cb (GtkComboBox *combo_box, ArvViewer *viewer)
 	GtkTreeModel *list_store;
 	GstCaps *caps;
 	GstElement *ffmpegcolorspace;
-	GstElement *ximagesink;
+	GstElement *videosink;
+	GstBus *bus;
 	ArvPixelFormat pixel_format;
 	char *camera_id;
 	char *string;
@@ -421,6 +497,7 @@ arv_viewer_select_camera_cb (GtkComboBox *combo_box, ArvViewer *viewer)
 	double gain_min, gain_max;
 	gboolean auto_gain, auto_exposure;
 	const char *caps_string;
+	gboolean is_frame_rate_available;
 	gboolean is_exposure_available;
 	gboolean is_exposure_auto_available;
 	gboolean is_gain_available;
@@ -436,6 +513,7 @@ arv_viewer_select_camera_cb (GtkComboBox *combo_box, ArvViewer *viewer)
 	viewer->camera = arv_camera_new (camera_id);
 	g_free (camera_id);
 
+	viewer->rotation = 0;
 	viewer->stream = arv_camera_create_stream (viewer->camera, NULL, NULL);
 	if (viewer->stream == NULL) {
 		g_object_unref (viewer->camera);
@@ -472,6 +550,7 @@ arv_viewer_select_camera_cb (GtkComboBox *combo_box, ArvViewer *viewer)
 	auto_gain = arv_camera_get_gain_auto (viewer->camera) != ARV_AUTO_OFF;
 	auto_exposure = arv_camera_get_gain_auto (viewer->camera) != ARV_AUTO_OFF;
 
+	is_frame_rate_available = arv_camera_is_frame_rate_available (viewer->camera);
 	is_exposure_available = arv_camera_is_exposure_time_available (viewer->camera);
 	is_exposure_auto_available = arv_camera_is_exposure_auto_available (viewer->camera);
 	is_gain_available = arv_camera_is_gain_available (viewer->camera);
@@ -491,6 +570,8 @@ arv_viewer_select_camera_cb (GtkComboBox *combo_box, ArvViewer *viewer)
 	gtk_range_set_range (GTK_RANGE (viewer->exposure_hscale), 0.0, 1.0);
 	gtk_range_set_range (GTK_RANGE (viewer->gain_hscale), gain_min, gain_max);
 
+	gtk_widget_set_sensitive (viewer->frame_rate_entry, is_frame_rate_available);
+
 	string = g_strdup_printf ("%g", frame_rate);
 	gtk_entry_set_text (GTK_ENTRY (viewer->frame_rate_entry), string);
 	g_free (string);
@@ -536,20 +617,23 @@ arv_viewer_select_camera_cb (GtkComboBox *combo_box, ArvViewer *viewer)
 
 	viewer->appsrc = gst_element_factory_make ("appsrc", NULL);
 	ffmpegcolorspace = gst_element_factory_make ("ffmpegcolorspace", NULL);
-	ximagesink = gst_element_factory_make ("xvimagesink", NULL);
-
-	g_object_set (ximagesink, "force-aspect-ratio", TRUE, "draw-borders", TRUE, "sync", FALSE, NULL);
+	viewer->transform = gst_element_factory_make ("videoflip", NULL);
+	videosink = gst_element_factory_make ("autovideosink", NULL);
 
 	if (g_str_has_prefix (caps_string, "video/x-raw-bayer")) {
 		GstElement *bayer2rgb;
 
 		bayer2rgb = gst_element_factory_make ("bayer2rgb", NULL);
 
-		gst_bin_add_many (GST_BIN (viewer->pipeline), viewer->appsrc, bayer2rgb, ffmpegcolorspace, ximagesink, NULL);
-		gst_element_link_many (viewer->appsrc, bayer2rgb, ffmpegcolorspace, ximagesink, NULL);
+		gst_bin_add_many (GST_BIN (viewer->pipeline), viewer->appsrc, bayer2rgb,
+				  ffmpegcolorspace, viewer->transform, videosink, NULL);
+		gst_element_link_many (viewer->appsrc, bayer2rgb,
+				       ffmpegcolorspace, viewer->transform, videosink, NULL);
 	} else {
-		gst_bin_add_many (GST_BIN (viewer->pipeline), viewer->appsrc, ffmpegcolorspace, ximagesink, NULL);
-		gst_element_link_many (viewer->appsrc, ffmpegcolorspace, ximagesink, NULL);
+		gst_bin_add_many (GST_BIN (viewer->pipeline), viewer->appsrc,
+				  ffmpegcolorspace, viewer->transform, videosink, NULL);
+		gst_element_link_many (viewer->appsrc, ffmpegcolorspace,
+				       viewer->transform, videosink, NULL);
 	}
 
 	caps = gst_caps_from_string (caps_string);
@@ -561,10 +645,11 @@ arv_viewer_select_camera_cb (GtkComboBox *combo_box, ArvViewer *viewer)
 	gst_app_src_set_caps (GST_APP_SRC (viewer->appsrc), caps);
 	gst_caps_unref (caps);
 
-	gst_element_set_state (viewer->pipeline, GST_STATE_PLAYING);
+	bus = gst_pipeline_get_bus (GST_PIPELINE (viewer->pipeline));
+	gst_bus_set_sync_handler (bus, (GstBusSyncHandler) bus_sync_handler, viewer);
+	gst_object_unref (bus);
 
-	g_assert (viewer->video_window_xid != 0);
-	gst_x_overlay_set_window_handle (GST_X_OVERLAY (ximagesink), viewer->video_window_xid);
+	gst_element_set_state (viewer->pipeline, GST_STATE_PLAYING);
 
 	g_signal_connect (viewer->stream, "new-buffer", G_CALLBACK (arv_viewer_new_buffer_cb), viewer);
 }
@@ -638,6 +723,9 @@ arv_viewer_new (void)
 	viewer->gain_hscale = GTK_WIDGET (gtk_builder_get_object (builder, "gain_hscale"));
 	viewer->auto_exposure_toggle = GTK_WIDGET (gtk_builder_get_object (builder, "auto_exposure_togglebutton"));
 	viewer->auto_gain_toggle = GTK_WIDGET (gtk_builder_get_object (builder, "auto_gain_togglebutton"));
+	viewer->rotate_cw_button = GTK_WIDGET (gtk_builder_get_object (builder, "rotate_cw_button"));
+	viewer->flip_vertical_toggle = GTK_WIDGET (gtk_builder_get_object (builder, "flip_vertical_togglebutton"));
+	viewer->flip_horizontal_toggle = GTK_WIDGET (gtk_builder_get_object (builder, "flip_horizontal_togglebutton"));
 
 	g_object_unref (builder);
 
@@ -654,6 +742,9 @@ arv_viewer_new (void)
 
 	g_signal_connect (viewer->main_window, "destroy", G_CALLBACK (arv_viewer_quit_cb), viewer);
 	g_signal_connect (viewer->snapshot_button, "clicked", G_CALLBACK (arv_viewer_snapshot_cb), viewer);
+	g_signal_connect (viewer->rotate_cw_button, "clicked", G_CALLBACK (arv_viewer_rotate_cw_cb), viewer);
+	g_signal_connect (viewer->flip_horizontal_toggle, "clicked", G_CALLBACK (arv_viewer_flip_horizontal_cb), viewer);
+	g_signal_connect (viewer->flip_vertical_toggle, "clicked", G_CALLBACK (arv_viewer_flip_vertical_cb), viewer);
 	g_signal_connect (viewer->camera_combo_box, "changed", G_CALLBACK (arv_viewer_select_camera_cb), viewer);
 
 	g_signal_connect (viewer->frame_rate_entry, "changed", G_CALLBACK (arv_viewer_frame_rate_entry_cb), viewer);
@@ -734,6 +825,8 @@ main (int argc,char *argv[])
 
 	arv_debug_enable (arv_viewer_option_debug_domains);
 
+	arv_enable_interface ("Fake");
+
 #ifdef ARAVIS_WITH_NOTIFY
 	notify_init ("Aravis Viewer");
 #endif
